[![Build Status](https://travis-ci.org/Malk123/simple-annotation.svg?branch=master)](https://travis-ci.org/Malk123/simple-annotation)
[![Coverage Status](https://coveralls.io/repos/github/Malk123/simple-annotation/badge.svg?branch=master)](https://coveralls.io/github/Malk123/simple-annotation?branch=master)
[![npm version](https://badge.fury.io/js/simple-annotation.svg)](https://badge.fury.io/js/simple-annotation)
![npm](https://img.shields.io/npm/l/express.svg)
# Outdated: Simple Annotation
Simple Annotation ist ein Modul für NodeJS.
Mit diesem Modul können Sie einfach Annotationen zu NodeJS hinzufügen.
Das Modul sucht nach Kommentaren mit Annotationen unter definierten Pfaden.
Danach gibt das Plugin den Pfad zur Datei den ValueType und das Object (ReturnType) was sich unter der Annotationen befindet zurück.

## Installation
npm i simple-annotation

## Beispiel
Beispiel Annotation
```javascript
/**
 * @AnnotationClassString AnnotationClassString
 * @AnnotationClassObject {"hello": 123}
 * @AnnotationClassArray [1234]
 * @AnnotationClassInt 12345
 */
class test{

    /**
     * @AnnotationES6Function AnnotationES6Function
     */
    myTestFunction1(str){
        return str;
    }
}
module.exports = test;
```
In dem Beispiel versuchen wir die Annotation "AnnotationES6Function" zu finden.
```javascript

var Annotation = require('simple-annotation');

Annotation.registerAnnotation(
    'AnnotationES6Function', // Annotation Name
    'string', // Annotation Value Type   {string, int, array, object, empty}
    'ES6function' // Annotation Return Type   {ES6class, ES6function, var, function}
);

var obj = new Annotation();

// Important !! Add only absolute paths, relative paths will be ignored.
obj.setPaths([
    __dirname+'/*/es6TestClass.js',
    __dirname+'/*/test.js',
    __dirname+'/*/function*.js',
    __dirname+'/*/var.js'
]);

var all = obj.findAll();
var one = obj.find('AnnotationES6Function');

for(var i in all){
    console.log(all[i]);
}

```

## Annotation Erstellen
```javascript
Annotation.registerAnnotation(
    'AnnotationES6Function', // Annotation Name
    'string', // Annotation Value Type   {string, int, array, object, empty}
    'ES6function' // Annotation Return Type   {ES6class, ES6function, var, function}
);
```

## Value/Return Types
Was sind Value/Return Types?
Ein "Valuetype" ist die rechte Seite der Annotation. Er wird bei der Abfrage der Annotation mit zurück gegeben.
Der "ReturnType" muss dem Object entsprechen über dem die Annotation sich befindet.  
```javascript
/**
* @AnnotationName ValueType
*/
module.exports = function ReturnType(str){
    return str;
};
```

**Alle vorkonfigurierten Typen sind überschreibbar.**

### Annotation ReturnType

| Name | Typ
| -------- | --------
| ES6class   | ECMA Script 6 Class
| ES6function   | ECMA Script 6 Function
| function   | <= ES5 Functions
| var   | <= ES5 Functions Variable

### Annotation ValueType

| Name | Typ |
| -------- | -------- |
| string   | string   |
| array   | array   |
| object   | object   |
| int   | integer   |
| empty | empty string|

### Vorkonfigurirte Rückgabemuster

#### <= ES5 function

```javascript

//Function 1
module.exports = function myTestFunction1(str){
    return str;
};

//Function 2
var myTestFunction2 = (str) => {
    return str;
};
exports.myTestFunction2 = myTestFunction2;

//Function 3
const myTestFunction3 = (str) => {
    return str;
};
exports.myTestFunction3 = myTestFunction3;

//Function 4
let myTestFunction5 = (str) => {
    return str;
};
exports.myTestFunction5 = myTestFunction5;

//Function 5
exports.myTestFunction7 = (str) => {
    return str;
};

```

#### <= ES5 variable
```javascript
var testVar = "test123Variable";
exports.testVar = testVar;
```



## Type erstellen
### ValueType
```javascript
var Annotation = require('simple-annotation');
Annotation.registerAnnotationValueType(
    'array',
    function(attr){
        return JSON.parse(attr);
    }
);
```
### ReturnType
```javascript
var Annotation = require('simple-annotation');
Annotation.registerAnnotationReturnType(
    'ES6class',
    function(attr){

        const regex = /^.*class (.*?)$/;
        let a = attr.str.match(regex);

        if(a !== null){
            var s = require(attr.file);
            return new s();
        }

        return null;
    }
);
```
## ToDo

- findBy() Funktion einfügen
- Refactoring (DRY, KISS, more Comments)



